@@ -1,29 +1,30 @@
-#' @include colour.R utilities.R
+#' @include colour.R
 NULL
 
-# Colour scales constructor for ggplot2 ========================================
-# Colour scale constructor
-#
-# Builds discrete or continuous scale for ggplot2 according to the color
-#  scheme used.
-# @param aesthetics The names of the aesthetics that this scale works with.
-# @param palette A \code{\link{character}} string giving the name of
-#  the palette to be used (see \code{\link{colour}}).
-# @param reverse A \code{\link{logical}} scalar specifying if the resulting
-#  vector of colours should be reversed.
-# @param ... Further arguments passed to \code{\link[ggplot2]{discrete_scale}}
-#  or \code{\link[ggplot2]{continuous_scale}}, used respectively for
-#  qualitative data and diverging/sequential data.
-# @author N. Frerebeau
-scale <- function(aesthetics, palette, reverse = FALSE, ...) {
-  # Check required package
-  checkPackage("ggplot2")
-  # Get palette
-  scheme <- colour(palette, reverse, names = FALSE)
-  type <- attr(scheme, "type")
-  interpolate <- attr(scheme, "interpolate")
-  missing <- attr(scheme, "missing")
-  max <- attr(scheme, "max")
+## Colour scales constructor for ggplot2 =======================================
+#' Colour scale constructor
+#'
+#' Builds discrete or continuous scale for 'ggplot2' according to the color
+#'  scheme used.
+#' @param aesthetics The names of the aesthetics that this scale works with.
+#' @param palette A \code{\link{character}} string giving the name of
+#'  the palette to be used (see \code{\link{colour}}).
+#' @param reverse A \code{\link{logical}} scalar specifying if the resulting
+#'  vector of colours should be reversed.
+#' @param ... Further arguments passed to \code{\link[ggplot2]{discrete_scale}}
+#'  or \code{\link[ggplot2]{continuous_scale}}, used respectively for
+#'  qualitative data and diverging/sequential data.
+#' @author N. Frerebeau
+#' @keywords internal
+#' @noRd
+scale <- function(aesthetics, scale_name, reverse = FALSE, midpoint = 0, ...) {
+  # Get colour palette and scheme information
+  palette <- colour(scale_name, reverse, names = FALSE)
+  type <- attr(palette, "type")
+  interpolate <- attr(palette, "interpolate")
+  missing <- attr(palette, "missing")
+  max <- attr(palette, "max")
+
   # Build scale
   scale_arguments <- list(...)
   if (!("na.value" %in% names(scale_arguments))) {
@@ -32,19 +33,33 @@ scale <- function(aesthetics, palette, reverse = FALSE, ...) {
   if (!("guide" %in% names(scale_arguments))) {
     scale_arguments[["guide"]] <- if(interpolate) "colourbar" else "legend"
   }
+
   if (type == "qualitative") {
-    do.call(
-      ggplot2::discrete_scale,
-      c(aesthetics, palette, scheme, scale_arguments)
-    )
+    do.call(ggplot2::discrete_scale,
+            c(aesthetics, scale_name, palette, scale_arguments))
   } else {
+    palette <- scales::gradient_n_pal(palette(max))
+    if (type == "diverging") {
+      scale_arguments[["rescaler"]] <- mid_rescaler(mid = midpoint)
+    }
+
     do.call(
       ggplot2::continuous_scale,
-      c(aesthetics, palette, scales::gradient_n_pal(scheme(max)), scale_arguments)
+      c(aesthetics, scale_name, palette, scale_arguments)
     )
   }
 }
 
+## COPY FROM GGPLOT2 NON-EXPORTS ===============================================
+#' @importFrom scales rescale_mid
+#' @keywords internal
+#' @noRd
+mid_rescaler <- function(mid) {
+  function(x, to = c(0, 1), from = range(x, na.rm = TRUE)) {
+    scales::rescale_mid(x, to, from, mid)
+  }
+}
+
 # Discrete and gradient colour scales for ggplot2 ==============================
 #' Paul Tol's Colour Schemes for ggplot2
 #'
@@ -91,8 +106,7 @@ scale <- function(aesthetics, palette, reverse = FALSE, ...) {
 scale_colour_tol <- function(..., palette, reverse = FALSE, aesthetics = "colour") {
   # Deprecate
   .Deprecated()
-  # Check required package
-  checkPackage("ggplot2")
+
   paul_tol <- c("bright", "vibrant", "muted", "light", "rainbow",
                 "sunset", "BuRd", "PRGn", "YlOrBr", "smooth rainbow")
   palette <- match.arg(palette, paul_tol, several.ok = FALSE)
@@ -107,8 +121,7 @@ scale_color_tol <- scale_colour_tol
 scale_fill_tol <- function(..., palette, reverse = FALSE, aesthetics = "fill") {
   # Deprecate
   .Deprecated()
-  # Check required package
-  checkPackage("ggplot2")
+
   paul_tol <- c("bright", "vibrant", "muted", "light", "rainbow",
                 "sunset", "BuRd", "PRGn", "YlOrBr", "smooth rainbow")
   palette <- match.arg(palette, paul_tol, several.ok = FALSE)
