@@ -1,10 +1,10 @@
-library("ggplot2")
+library(ggplot2)
 
 # Sequential data
 ggplot(faithfuld, aes(waiting, eruptions, fill = density)) +
   geom_raster() +
-  scale_fill_YlOrBr()
+  khroma::scale_fill_YlOrBr()
 
 ggplot(faithfuld, aes(waiting, eruptions, fill = density)) +
   geom_raster() +
-  scale_fill_smoothrainbow(reverse = TRUE)
+  khroma::scale_fill_smoothrainbow(reverse = TRUE)
